#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_NOT_EQUAL_WITH_EQUAL_NANS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_IS_NOT_EQUAL_WITH_EQUAL_NANS_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/simd/is_not_equal_with_equal_nans.hpp>

#endif
